Cosmic in Python — Cosmic 0.1.4 documentation

### Navigation

- index
- modules |
- next |
- Cosmic 0.1.4 documentation »

# Cosmic in Python

Here you will find the documentation for the Python implementation of Cosmic. The tutorial should be the best way to get up and running.

Contents:

- Overview
  - Motivation
  - The Universal Client
  - REST and RPC
  - Architecture
  - Built on Teleport
  - Built on Flask
  - Hypermedia with JSON HAL
- Guide
  - Installation
  - What’s in an API?
  - Client and Server
  - RPC via Actions
  - Models as Data Types
  - REST via Models
    - get_by_id
    - save
    - delete
    - get_list
  - Authentication
- Tutorial
  - Step 0: Blank API
  - Step 1: Single-function API
  - Step 2: Defining a Custom Data Type
  - Step 3: RESTful API
  - Step 4: Authenticating
- Reference
  - APIs
  - HTTP Endpoints
  - Exceptions
  - Tools and Helpers

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Cosmic 0.1.4 documentation »